@@ -26,11 +26,12 @@ describe 'nova::compute::rbd' do
     { :libvirt_rbd_user => 'nova' }
   end
 
-  shared_examples_for 'nova compute rbd' do
+  shared_examples_for 'nova::compute::rbd' do
 
     it { is_expected.to contain_class('nova::params') }
 
     it 'configure nova.conf with default parameters' do
+        is_expected.to contain_nova_config('libvirt/rbd_secret_uuid').with_ensure('absent')
         is_expected.to contain_nova_config('libvirt/images_rbd_pool').with_value('rbd')
         is_expected.to contain_nova_config('libvirt/images_rbd_ceph_conf').with_value('/etc/ceph/ceph.conf')
         is_expected.to contain_nova_config('libvirt/rbd_user').with_value('nova')
@@ -170,6 +171,21 @@ describe 'nova::compute::rbd' do
     end
   end
 
+  shared_examples_for 'nova::compute::rbd in Debian' do
+    it 'should install the qemu-block-extra package' do
+      is_expected.to contain_package('qemu-block-extra').with(
+        :ensure => 'present',
+        :tag    => ['openstack', 'nova-support-package'],
+      )
+    end
+  end
+
+  shared_examples_for 'nova::compute::rbd in RedHat' do
+    it 'should not install the qemu-block-extra package' do
+      is_expected.to_not contain_package('qemu-block-extra')
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -186,7 +202,10 @@ describe 'nova::compute::rbd' do
           { :ceph_client_package => 'ceph-common' }
         end
       end
-      it_configures 'nova compute rbd'
+      it_configures 'nova::compute::rbd'
+      if facts[:osfamily] == 'Debian'
+        it_configures "nova::compute::rbd in #{facts[:osfamily]}"
+      end
     end
   end
 
