@@ -25,11 +25,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
       end
 
-      it { is_expected.to contain_exec('networking-refresh').with(
-        :command     => '/sbin/ifdown -a ; /sbin/ifup -a',
-        :refreshonly => true
-      )}
-
       it 'does not configure auth_strategy' do
         is_expected.not_to contain_nova_config('api/auth_strategy')
       end
@@ -80,8 +75,6 @@ describe 'nova' do
       end
 
       it 'configures various things' do
-        is_expected.to contain_nova_config('glance/endpoint_override').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('glance/num_retries').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/state_path').with_value('/var/lib/nova')
         is_expected.to contain_oslo__concurrency('nova_config').with(
           :lock_path => platform_params[:lock_path]
@@ -91,7 +84,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
         is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('cinder/cross_az_attach').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
@@ -104,6 +96,9 @@ describe 'nova' do
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('<SERVICE DEFAULT>')
+        # TODO(tkajinam): Uncomment this when we change default value of
+        #                 nova::instance_name_template
+        # is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('<SERVICE DEFAULT>')
       end
 
     end
@@ -112,8 +107,6 @@ describe 'nova' do
 
       let :params do
         {
-          :glance_endpoint_override                => 'http://localhost:9292',
-          :glance_num_retries                      => 3,
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
           :long_rpc_timeout                        => '1800',
@@ -149,7 +142,6 @@ describe 'nova' do
           :notification_topics                     => 'openstack',
           :notification_format                     => 'unversioned',
           :report_interval                         => '60',
-          :cross_az_attach                         => true,
           :ovsdb_connection                        => 'tcp:127.0.0.1:6640',
           :upgrade_level_cells                     => '1.0.0',
           :upgrade_level_cert                      => '1.0.0',
@@ -166,7 +158,7 @@ describe 'nova' do
           :console_ssl_ciphers                     => 'kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES',
           :console_ssl_minimum_version             => 'tlsv1_2',
           :dhcp_domain                             => 'foo',
-
+          :instance_name_template                  => 'instance-%08x',
         }
       end
 
@@ -184,11 +176,6 @@ describe 'nova' do
         })
       end
 
-      it 'configures glance parameters' do
-        is_expected.to contain_nova_config('glance/endpoint_override').with_value('http://localhost:9292')
-        is_expected.to contain_nova_config('glance/num_retries').with_value(3)
-      end
-
       it 'configures auth_strategy' do
         is_expected.to contain_nova_config('api/auth_strategy').with_value('foo')
       end
@@ -258,13 +245,13 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
         is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
         is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('1800')
-        is_expected.to contain_nova_config('cinder/cross_az_attach').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('tlsv1_2')
         is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('foo')
+        is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('instance-%08x');
       end
 
       context 'with multiple notification_driver' do
@@ -423,9 +410,6 @@ describe 'nova' do
       end
 
       it { is_expected.to contain_nova_config('DEFAULT/enabled_ssl_apis').with_value('osapi_compute') }
-      it { is_expected.to contain_nova_config('ssl/ca_file').with_value('/path/to/ca') }
-      it { is_expected.to contain_nova_config('ssl/cert_file').with_value('/path/to/cert') }
-      it { is_expected.to contain_nova_config('ssl/key_file').with_value('/path/to/key') }
       it { is_expected.to contain_nova_config('wsgi/ssl_ca_file').with_value('/path/to/ca') }
       it { is_expected.to contain_nova_config('wsgi/ssl_cert_file').with_value('/path/to/cert') }
       it { is_expected.to contain_nova_config('wsgi/ssl_key_file').with_value('/path/to/key') }
@@ -456,9 +440,9 @@ describe 'nova' do
       end
 
       it { is_expected.to contain_nova_config('DEFAULT/enabled_ssl_apis').with_ensure('absent') }
-      it { is_expected.to contain_nova_config('ssl/ca_file').with_ensure('absent') }
-      it { is_expected.to contain_nova_config('ssl/cert_file').with_ensure('absent') }
-      it { is_expected.to contain_nova_config('ssl/key_file').with_ensure('absent') }
+      it { is_expected.to contain_nova_config('wsgi/ssl_ca_file').with_ensure('absent') }
+      it { is_expected.to contain_nova_config('wsgi/ssl_cert_file').with_ensure('absent') }
+      it { is_expected.to contain_nova_config('wsgi/ssl_key_file').with_ensure('absent') }
     end
 
     context 'with allocation ratios set' do
